@@ -223,7 +223,7 @@ class TestConvertStringToCaseInsensitive(base.BaseTestCase):
 
     def test_convert_string_to_lower(self):
         result = converters.convert_string_to_case_insensitive(u"THIS Is tEsT")
-        self.assertTrue(isinstance(result, six.string_types))
+        self.assertIsInstance(result, six.string_types)
 
     def test_assert_error_on_non_string(self):
         for invalid in [[], 123]:
@@ -270,3 +270,64 @@ class TestConvertProtocol(base.BaseTestCase):
     def test_unknown_string(self):
         with testtools.ExpectedException(n_exc.InvalidInput):
             converters.convert_to_protocol("Invalid")
+
+
+class TestConvertToString(base.BaseTestCase):
+
+    def test_data_is_string(self):
+        self.assertEqual('10000', converters.convert_to_string('10000'))
+
+    def test_data_is_integer(self):
+        self.assertEqual('10000', converters.convert_to_string(10000))
+
+    def test_data_is_integer_zero(self):
+        self.assertEqual('0', converters.convert_to_string(0))
+
+    def test_data_is_none(self):
+        self.assertIsNone(converters.convert_to_string(None))
+
+    def test_data_is_empty_list(self):
+        self.assertEqual('[]', converters.convert_to_string([]))
+
+    def test_data_is_list(self):
+        self.assertEqual("[1, 2, 3]", converters.convert_to_string([1, 2, 3]))
+
+    def test_data_is_empty_dict(self):
+        self.assertEqual('{}', converters.convert_to_string({}))
+
+    def test_data_is_dict(self):
+        self.assertEqual("{'foo': 'bar'}",
+                         converters.convert_to_string({'foo': 'bar'}))
+
+
+class TestConvertUppercasePrefix(base.BaseTestCase):
+
+    def test_prefix_not_present(self):
+        self.assertEqual('foobar',
+                         converters.convert_prefix_forced_case('foobar',
+                                                               'bar'))
+
+    def test_prefix_no_need_to_replace(self):
+        self.assertEqual('FOObar',
+                         converters.convert_prefix_forced_case('FOObar',
+                                                               'FOO'))
+
+    def test_ucfirst_prefix_converted_1(self):
+        self.assertEqual('Foobar',
+                         converters.convert_prefix_forced_case('foobar',
+                                                               'Foo'))
+
+    def test_lc_prefix_converted_2(self):
+        self.assertEqual('foobar',
+                         converters.convert_prefix_forced_case('fOobar',
+                                                               'foo'))
+
+    def test_mixed_prefix_converted_1(self):
+        self.assertEqual('fOoXbar',
+                         converters.convert_prefix_forced_case('Fooxbar',
+                                                               'fOoX'))
+
+    def test_shorter_string(self):
+        self.assertEqual('fo',
+                         converters.convert_prefix_forced_case('fo',
+                                                               'foo'))
